@@ -16,14 +16,15 @@ class quantum_lab():
         # self.shot = shot
         self.resourceId = resourceId
         # self.filePath = filePath
-        self.volumeName = self.getDirpath(volumeName)
+        self.volumeName = volumeName
+        self.volumePath = self.getDirpath(volumeName)
         self.resourceName = res.getResourceName(resourceId)
         self.url = "http://job-management.qcc.svc.cluster.local"
 
-        if not isinstance(self.volumeName, str):
-            raise TypeError(f"{volumeName} not found.")
+        if not isinstance(self.volumePath, str):
+            raise ValueError(f"[ERROR] Volume {volumeName} not found in home. -> (/home/jovyan)")
         if "ERROR" in self.resourceName:
-            raise ValueError(f"{resourceId} not found.")
+            raise ValueError(f"[ERROR] resourceID {resourceId} not found. Please check resources's information.")
 
 
     def getDirpath(self, dirPath):
@@ -44,12 +45,22 @@ class quantum_lab():
         return {response.json()['error']}
 
 
-    def createPrint(self,
+    def createProcess(self,
             uploadType: str, 
             shot: int, 
-            filePath: str, 
+            fileName: str, 
             timeout = 120
         ):
+        ## check file.
+        filePath = ""
+        fileList = os.listdir(self.volumePath)
+        for files in fileList:
+            if files == fileName:
+                filePath = f"{self.volumePath}/{fileName}"
+
+        if filePath == "":
+            raise ValueError(f"File {fileName} not found.")
+
         url_path = f"{self.url}/qcc/notebook/job"
 
         headers = {
@@ -98,8 +109,18 @@ class quantum_lab():
     def create(self, 
             uploadType: str, 
             shot: int, 
-            filePath: str, 
+            fileName: str, 
         ):
+        ## check file.
+        filePath = ""
+        fileList = os.listdir(self.volumePath)
+        for files in fileList:
+            if files == fileName:
+                filePath = f"{self.volumePath}/{fileName}"
+
+        if filePath == "":
+            raise ValueError(f"File {fileName} not found.")
+
         url_path = f"{self.url}/qcc/notebook/job"
 
         headers = {
